summaryrefslogtreecommitdiff
path: root/git/config.py
diff options
context:
space:
mode:
authorKostis Anagnostopoulos <ankostis@gmail.com>2016-10-21 00:33:43 +0200
committerGitHub <noreply@github.com>2016-10-21 00:33:43 +0200
commitafcd64ebbb770908bd2a751279ff070dea5bb97c (patch)
tree0674f49f45996d533890e0f67498a6038c590168 /git/config.py
parentaab7dc2c7771118064334ee475dff8a6bb176b57 (diff)
parent66c41eb3b2b4130c7b68802dd2078534d1f6bf7a (diff)
downloadgitpython-afcd64ebbb770908bd2a751279ff070dea5bb97c.tar.gz
Merge pull request #539 from bryant1410/typos
Fix some typos
Diffstat (limited to 'git/config.py')
-rw-r--r--git/config.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/git/config.py b/git/config.py
index eddfac15..00943b58 100644
--- a/git/config.py
+++ b/git/config.py
@@ -194,7 +194,7 @@ class GitConfigParser(with_metaclass(MetaParserBuilder, cp.RawConfigParser, obje
configuration files have been included
:param merge_includes: if True, we will read files mentioned in [include] sections and merge their
contents into ours. This makes it impossible to write back an individual configuration file.
Thus, if you want to modify a single conifguration file, turn this off to leave the original
dataset unaltered when reading it."""
cp.RawConfigParser.__init__(self, dict_type=OrderedDict)
@@ -271,7 +271,7 @@ class GitConfigParser(with_metaclass(MetaParserBuilder, cp.RawConfigParser, obje
"""A direct copy of the py2.4 version of the super class's _read method
to assure it uses ordered dicts. Had to change one line to make it work.
- Future versions have this fixed, but in fact its quite embarassing for the
+ Future versions have this fixed, but in fact its quite embarrassing for the
guys not to have done it right in the first place !
Removed big comments to make it more compact.
@@ -468,7 +468,7 @@ class GitConfigParser(with_metaclass(MetaParserBuilder, cp.RawConfigParser, obje
# end assert multiple files
if self._has_includes():
- log.debug("Skipping write-back of confiuration file as include files were merged in." +
+ log.debug("Skipping write-back of configuration file as include files were merged in." +
"Set merge_includes=False to prevent this.")
return
# end
@@ -194,7 +194,7 @@ class GitConfigParser(with_metaclass(MetaParserBuilder, cp.RawConfigParser, obje
:param merge_includes: if True, we will read files mentioned in [include] sections and merge their
contents into ours. This makes it impossible to write back an individual configuration file.
- Thus, if you want to modify a single conifguration file, turn this off to leave the original
+ Thus, if you want to modify a single configuration file, turn this off to leave the original
dataset unaltered when reading it."""
cp.RawConfigParser.__init__(self, dict_type=OrderedDict)